==> plasmidhunter-1.3.tar.gz: plasmidhunter-1.3/README.md <==
<p>
presented by Institute of Food Safety and Health, Illinois Institute of Technology
</p>

# PlasmidHunter: Accurate and Fast Plasmid Prediction Based on Gene Content Using Machine Learning 

Plasmids are extrachromosomal DNA found in microorganisms. They often carry beneficial genes that help bacteria adapt to harsh conditions. Plasmids are also important tools in genetic engineering, gene therapy, and drug production. However, it can be difficult to identify plasmid sequences from chromosomal sequences in genomic and metagenomic data. Here, we have developed a new tool called PlasmidHunter, which uses machine learning to predict plasmid sequences based on gene content profile. PlasmidHunter achieved high accuracies (up to 97.6%) and high speeds in benchmark tests including both simulated contigs and real metagenomic plasmidome data, outperforming other existing tools.

Keywords: artificial intelligence (AI), machine learning (ML), plasmid prediction, genomic sequencing

## Installation and run
conda create -n plasmidhunter -c bioconda -y python=3.10 diamond=2.1.8 prodigal

conda activate plasmidhunter

pip install plasmidhunter

plasmidhunter -h
## Result Interpretation
The result is a tab-delimited table showing the prediction of each sequence. The columns include Prediction (0: chromosome, 1: plasmid), Probability of 0 (chromosome), and Probability of 1 (plasmid). 

## Citation
PlasmidHunter: Accurate and fast prediction of plasmid sequences using gene content profile and machine learning

Renmao Tian, Jizhong Zhou, Behzad Imanian

bioRxiv 2023.02.01.526640; doi: https://doi.org/10.1101/2023.02.01.526640

## Contact
If you have any questions, please contact Renmao Tian (tianrenmao[at]gmail.com) or Behzad Imanian (bimanian[at]iit.edu).

## License
Educational Community License, Version 2.0

==> plasmidhunter-1.4.tar.gz: plasmidhunter-1.4/README.md <==
<p>
presented by Institute of Food Safety and Health, Illinois Institute of Technology
</p>

# PlasmidHunter: Accurate and Fast Plasmid Prediction Based on Gene Content Using Machine Learning 

Plasmids are extrachromosomal DNA found in microorganisms. They often carry beneficial genes that help bacteria adapt to harsh conditions. Plasmids are also important tools in genetic engineering, gene therapy, and drug production. However, it can be difficult to identify plasmid sequences from chromosomal sequences in genomic and metagenomic data. Here, we have developed a new tool called PlasmidHunter, which uses machine learning to predict plasmid sequences based on gene content profile. PlasmidHunter achieved high accuracies (up to 97.6%) and high speeds in benchmark tests including both simulated contigs and real metagenomic plasmidome data, outperforming other existing tools.

Keywords: artificial intelligence (AI), machine learning (ML), plasmid prediction, genomic sequencing

## Installation and run
conda create -n plasmidhunter -c bioconda -c conda-forge -y python=3.10 diamond=2.1.8 prodigal

conda activate plasmidhunter

pip install plasmidhunter

plasmidhunter -h

## Result Interpretation
The result is a tab-delimited table showing the prediction of each sequence. The columns include Prediction (0: chromosome, 1: plasmid), Probability of 0 (chromosome), and Probability of 1 (plasmid). 

## Change Log
v1.1 9/1/2022

PlasmidHunter is now using much less memory.

v1.2 11/23/2023

PlasmidHunter has an expanded database for a higher annotation rate.

PlasmidHunter is now accepting shorter contigs down to 1 Kbp and has a higher accuracy for short contigs.

v1.3 4/2024
Fixed some minor bugs

v1.4 5/17/2024

Converted model and feature pickle file into parameter file and text file, respectively.

## Citation
PlasmidHunter: Accurate and fast prediction of plasmid sequences using gene content profile and machine learning

Renmao Tian, Jizhong Zhou, Behzad Imanian

bioRxiv 2023.02.01.526640; doi: https://doi.org/10.1101/2023.02.01.526640

## Contact
If you have any questions, please contact Renmao Tian (tianrenmao[at]gmail.com) or Behzad Imanian (bimanian[at]iit.edu).

## License
Educational Community License, Version 2.0
